CedarBackup3.actions.purge — cedar-backup3 3.10.0 documentation

# CedarBackup3.actions.purge

Implements the standard ‘purge’ action. :author: Kenneth J. Pronovici <pronovic@ieee.org>

## Module Contents

CedarBackup3.actions.purge.logger

CedarBackup3.actions.purge.executePurge(configPath, options, config)

  Executes the purge backup action.

  For each configured directory, we create a purge item list, remove from the list anything that’s younger than the configured retain days value, and then purge from the filesystem what’s left.

  Parameters:

    - configPath (String representing a path on disk) – Path to configuration file on disk

    - options (Options object) – Program command-line options

    - config (Config object) – Program configuration

  Raises:

    ValueError – Under many generic error conditions